@@ -42,17 +42,6 @@ pub(super) fn map_client_msg(
                 error
             );
 
-            Mapping {
-                op: NodeDuty::NoOp,
-                ctx: None,
-            }
-        }
-        DataMsg::SupportingInfo(msg) => {
-            warn!(
-                "A node should never receive a DataMsg::SupportingInfo {:?}",
-                msg
-            );
-
             Mapping {
                 op: NodeDuty::NoOp,
                 ctx: None,
